From 69cdb10295c3aae5791273cea436263011ed1e50 Mon Sep 17 00:00:00 2001
From: Heiko Folkerts <heiko@hfolkerts.de>
Date: Tue, 16 Jul 2013 20:01:51 +0200
Subject: [PATCH] Patch for #2871: unchecking all NVDA modifier keys in the
 keyboard settings dialog should give an error.

---
 source/gui/settingsDialogs.py | 9 +++++++++
 user_docs/en/userGuide.t2t    | 1 +
 2 files changed, 10 insertions(+)

diff --git a/source/gui/settingsDialogs.py b/source/gui/settingsDialogs.py
index 28d89ea..f0c8b1e 100644
--- a/source/gui/settingsDialogs.py
+++ b/source/gui/settingsDialogs.py
@@ -652,6 +652,15 @@ class KeyboardSettingsDialog(SettingsDialog):
 		self.kbdList.SetFocus()
 
 	def onOk(self,evt):
+		# #2871: check wether at least one key is the nvda key.
+		if self.capsAsNVDAModifierCheckBox.IsChecked() == False and self.numpadInsertAsNVDAModifierCheckBox.IsChecked() == False and self.extendedInsertAsNVDAModifierCheckBox.IsChecked() == False:
+			log.error("Error when setting the key to use as NVDA key.") 
+			gui.messageBox(
+							# Translators: Message to report wrong configuration of the NVDA key
+							_("At least one key must be used as NVDA key. Without that you won't be able to access the NVDA dialogs any more."), 
+							# Translators: The title of the message box
+							_("Error"), wx.OK|wx.ICON_ERROR,self)
+			return
 		layout=self.kbdNames[self.kbdList.GetSelection()]
 		config.conf['keyboard']['keyboardLayout']=layout
 		config.conf["keyboard"]["useCapsLockAsNVDAModifierKey"]=self.capsAsNVDAModifierCheckBox.IsChecked()
diff --git a/user_docs/en/userGuide.t2t b/user_docs/en/userGuide.t2t
index c8e5462..06fb9b6 100644
--- a/user_docs/en/userGuide.t2t
+++ b/user_docs/en/userGuide.t2t
@@ -769,6 +769,7 @@ If this checkbox is checked, the extended insert key (usually found above the ar
 
 ==== Use numpad insert as an NVDA modifier key ====
 If this checkbox is checked, the insert key on the number pad can be used as an NVDA modifier key.
+If you uncheck all three check boxes for the NVDA modifier key the dialog will display an error message when you try to close it with OK. This is because without any key set as NVDA modifier key you won't be able to control NVDA via the keyboard.
 
 %kc:setting
 ==== Speak Typed Characters ====
-- 
1.8.3.msysgit.0

